@@ -353,13 +353,14 @@ class Customer(StripeObject):
         except CurrentSubscription.DoesNotExist:
             return False
 
-    def cancel(self):
+    def cancel(self, at_period_end=True):
         try:
             current = self.current_subscription
         except CurrentSubscription.DoesNotExist:
             return
-        sub = self.stripe_customer.cancel_subscription()
+        sub = self.stripe_customer.cancel_subscription(at_period_end=at_period_end)
         current.status = sub.status
+        current.cancel_at_period_end = sub.cancel_at_period_end
         current.period_end = convert_tstamp(sub, "current_period_end")
         current.save()
         cancelled.send(sender=self, stripe_response=sub)
@@ -451,6 +452,7 @@ class Customer(StripeObject):
                 )
                 sub_obj.amount = (sub.plan.amount / decimal.Decimal("100"))
                 sub_obj.status = sub.status
+                sub_obj.cancel_at_period_end = sub.cancel_at_period_end
                 sub_obj.start = convert_tstamp(sub.start)
                 sub_obj.quantity = sub.quantity
                 sub_obj.save()
@@ -466,6 +468,7 @@ class Customer(StripeObject):
                     ),
                     amount=(sub.plan.amount / decimal.Decimal("100")),
                     status=sub.status,
+                    cancel_at_period_end=sub.cancel_at_period_end,
                     start=convert_tstamp(sub.start),
                     quantity=sub.quantity
                 )
@@ -549,6 +552,7 @@ class CurrentSubscription(TimeStampedModel):
     # trialing, active, past_due, canceled, or unpaid
     # In progress of moving it to choices field
     status = models.CharField(max_length=25)
+    cancel_at_period_end = models.BooleanField()
     canceled_at = models.DateTimeField(null=True, blank=True)
     current_period_end = models.DateTimeField(null=True)
     current_period_start = models.DateTimeField(null=True)
@@ -567,7 +571,7 @@ class CurrentSubscription(TimeStampedModel):
         return self.current_period_end > timezone.now()
 
     def is_status_current(self):
-        return self.status in ["trialing", "active", "canceled"]
+        return self.status in [self.STATUS_TRIALING, self.STATUS_ACTIVE]
 
     def is_valid(self):
         return self.is_period_current() and self.is_status_current()
@@ -690,8 +694,12 @@ class Invoice(TimeStampedModel):
             cls.sync_from_stripe_data(stripe_invoice)
 
 
-class InvoiceItem(StripeObject):
+class InvoiceItem(TimeStampedModel):
+    """ Not inherited from StripeObject because there can be multiple invoice
+        items for a single stripe_id.
+    """
 
+    stripe_id = models.CharField(max_length=50)
     invoice = models.ForeignKey(Invoice, related_name="items")
     amount = models.DecimalField(decimal_places=2, max_digits=7)
     currency = models.CharField(max_length=10)
